@@ -3,6 +3,10 @@ import requests
 
 __all__ = ['getHome', 'getCategory', 'getLead', 'getUser', 'getTrack', 'getRandom']
 
+def getFeaturedGhosts():
+    response = requests.get("https://raw.githubusercontent.com/Calculus0972/Official_Featured_Ghosts/master/ghosts.json")
+    return response.json()
+
 def getHome():
     response = requests.get("https://www.freeriderhd.com?ajax=true")
     return response.json()
